freeslot(
"sfx_wcgun",
"sfx_wknif",
"sfx_wmgun",
"sfx_wpist",
"sfx_bjdie",
"S_WOLF_BJDIE",
"S_WOLF_BJDEAD",
"SPR2_DYIN"
)

states[S_WOLF_BJDIE] = {SPR_PLAY, SPR2_DYIN|FF_ANIMATE, 5*2, nil, 4, 2, S_WOLF_BJDEAD}
states[S_WOLF_BJDEAD] = {SPR_PLAY, SPR2_DEAD, -1, nil, 0, 0, S_NULL}

local SCREENHEIGHT = 0
local SCREENWIDTH = 0

local WEP_KNIFE = 1
local WEP_PISTOL = 2
local WEP_MACHINEGUN = 4
local WEP_CHAINGUN = 8

local WEAPONS = {
	{req = WEP_KNIFE, state = "KNIFE_IDLE"},
	{req = WEP_PISTOL, state = "PISTOL_IDLE"},
	{req = WEP_MACHINEGUN, state = "MGUN_IDLE"},
	{req = WEP_CHAINGUN, state = "CGUN_IDLE"}
}

//no contact damage from cez eggman
local function IgnoreEggman(mo, tmo)
	if (tmo.type == MT_PLAYER)
	and (tmo.skin == "bj") then
		return false
	end
end
addHook("MobjCollide", IgnoreEggman, MT_EGGMOBILE4)

local WEAPONSTATES = {}
local function ShootFakeRay(player, dist, sound)
	if not (player.wolfenstein.wep == WEP_KNIFE) then 
		if not (player.wolfenstein.ammo) then
			return
		end
		player.wolfenstein.ammo = $1-1
	end
	
	local ray = P_SPMAngle(player.mo, MT_WOLFBULLET, player.mo.angle, 0)

	if (player.wolfenstein.wep == WEP_KNIFE) 
		ray.knife = true
	end

	//hate
	if (mapheaderinfo[gamemap].lvlttl == "Black Core")
	and (mapheaderinfo[gamemap].actnum == 2) then
		ray.height = 128*player.mo.scale
	end

	if (sound) then
		S_StartSound(player.mo, sound)
	end
	
	ray.flags = $1|MF_MISSILE
	
	if not (ray)
	or not (ray.valid) then return end
	ray.hitdist = player.mo.height
	
	local z
	//higher up to better center shots
	//and make shooting better with slopes
	if (player.mo.eflags & MFE_VERTICALFLIP)
		z = (player.mo.z + player.mo.height) - (16*player.mo.scale)
	else
		z = player.mo.z + 16*player.mo.scale
	end
	ray.startz = z
	ray.z = z
	

	for i = 1,dist do
		if not (ray.valid) then
			return
		end
		
		P_RailThinker(ray)
		
		if not (ray.valid) then
			return
		end
		
		if (P_IsObjectOnGround(ray))
		and (R_PointToDist2(ray.z, 0, ray.startz, 0) > 48*player.mo.scale) //slope wiggle room
			P_RemoveMobj(ray)
			return
		end
	end
	
	if (ray.valid) then
		P_RemoveMobj(ray)
	end
end

local function ChangeWeaponState(player, newstate)
	local stateInfo = WEAPONSTATES[newstate]
	
	if not (stateInfo) then
		print("\$newstate\ is not a valid state, aborting.")
		return
	end
	
	player.wolfenstein.wepstate = newstate
	player.wolfenstein.animdelay = stateInfo.duration
	
	if (stateInfo.func) then
		stateInfo.func(player, stateInfo.var1, stateInfo.var2)
	end
end


local function CheckFireHeld(player, newstate)
	if (player.wolfenstein.fireheld)
	and (player.wolfenstein.ammo) then
		ChangeWeaponState(player, newstate)
	end
end

local function AddWeaponState(name, graphic, duration, func, var1, var2, nextstate)
	if not (name)
	or not (nextstate) then
		return
	end
	
	WEAPONSTATES[name] = {graphic = graphic, duration = duration, func = func, var1 = var1, var2 = var2, nextstate = nextstate}
end


//name, graphic, duration, function, var1, var2, nextstate
AddWeaponState("KNIFE_IDLE", "WFKNIF1", -1, nil, nil, nil, "KNIFE_ATTACK1")
AddWeaponState("KNIFE_ATTACK1", "WFKNIF2", 3, nil, nil, nil, "KNIFE_ATTACK2")
AddWeaponState("KNIFE_ATTACK2", "WFKNIF3", 3, nil, nil, nil, "KNIFE_ATTACK3")
AddWeaponState("KNIFE_ATTACK3", "WFKNIF4", 3, ShootFakeRay, 26, sfx_wknif, "KNIFE_ATTACK4")
AddWeaponState("KNIFE_ATTACK4", "WFKNIF5", 3, nil, nil, nil, "KNIFE_IDLE")

AddWeaponState("PISTOL_IDLE", "WFPIST1", -1, nil, nil, nil, "PISTOL_ATTACK1")
AddWeaponState("PISTOL_ATTACK1", "WFPIST2", 3, nil, nil, nil, "PISTOL_ATTACK2")
AddWeaponState("PISTOL_ATTACK2", "WFPIST3", 3, ShootFakeRay, 2048, sfx_wpist, "PISTOL_ATTACK3")
AddWeaponState("PISTOL_ATTACK3", "WFPIST4", 3, nil, nil, nil, "PISTOL_ATTACK4")
AddWeaponState("PISTOL_ATTACK4", "WFPIST5", 3, nil, nil, nil, "PISTOL_IDLE")

AddWeaponState("MGUN_IDLE", "WFMACH1", -1, nil, nil, nil, "MGUN_ATTACK1")
AddWeaponState("MGUN_ATTACK1", "WFMACH2", 2, nil, nil, nil, "MGUN_ATTACK2")
AddWeaponState("MGUN_ATTACK2", "WFMACH3", 2, ShootFakeRay, 2048, sfx_wmgun, "MGUN_ATTACK3")
AddWeaponState("MGUN_ATTACK3", "WFMACH4", 2, nil, nil, nil, "MGUN_ATTACK4")
AddWeaponState("MGUN_ATTACK4", "WFMACH5", 2, CheckFireHeld, "MGUN_ATTACK2", nil, "MGUN_IDLE")


AddWeaponState("CGUN_IDLE", "WFCHIN1", -1, nil, nil, nil, "CGUN_ATTACK1")
AddWeaponState("CGUN_ATTACK1", "WFCHIN2", 2, nil, nil, nil, "CGUN_ATTACK2")
AddWeaponState("CGUN_ATTACK2", "WFCHIN3", 2, ShootFakeRay, 2048, sfx_wcgun, "CGUN_ATTACK3")
AddWeaponState("CGUN_ATTACK3", "WFCHIN4", 2, ShootFakeRay, 2048, sfx_wcgun, "CGUN_ATTACK4")
AddWeaponState("CGUN_ATTACK4", "WFCHIN5", 2, CheckFireHeld, "CGUN_ATTACK2", nil, "CGUN_IDLE")


local function ChangeWeapon(player, wepNum, force)
	if not (player.wolfenstein.animdelay == -1)
	and not (force) then
		return
	end

	if not (player.wolfenstein.weps & WEAPONS[wepNum].req) then
		return
	end

	if (wepNum > #WEAPONS+1) then
		wepNum = 1
	elseif (wepNum < 1) then
		wepNum = WEAPONS+1
	end

	player.wolfenstein.wep = wepNum
	ChangeWeaponState(player, WEAPONS[wepNum].state)
end

local function GetEmeraldCount()
	if not (emeralds)
		return 0
	end
	
	local emeraldCount = 0
	local checkNum = 1
	for i = 1, 7, 1 do
		if (emeralds & checkNum) then
			emeraldCount = $1 + 1
		end
		
		checkNum = $1 * 2
	end
	
	return emeraldCount
end

local function WolfSetup(player)
	if not (player.wolfenstein) then
		player.wolfenstein = {
		health = 100,
		ammo = 16,
		weps = WEP_KNIFE|WEP_PISTOL,
		wep = 2,
		animdelay = -1,
		wepstate = "PISTOL_IDLE",
		fireheld = false,
		lastpickup = nil,
		lastpickuptime = 0,
		wolfcam = true,
		alwaysrun = true,
		grabbeditems = {}
		}
	end
	
	player.wolfenstein.animdelay = -1
	player.wolfenstein.wepstate = WEAPONS[player.wolfenstein.wep].state
	player.wolfenstein.grabbeditems = {}
	player.wolfenstein.fireheld = false
	player.wolfenstein.lastpickup = nil
	player.wolfenstein.lastpickuptime = 0
	player.wolfenstein.deathtime = nil


	local minAmmo = 16
	local emeraldCount = GetEmeraldCount()

	minAmmo = $1 + (6*emeraldCount)

	if (player.wolfenstein.ammo < minAmmo) then
		player.wolfenstein.ammo = minAmmo
	end
	
	//respawn
	if (player.wolfenstein.health < 1) then
		player.wolfenstein.health =  100
		player.wolfenstein.ammo = minAmmo
		player.wolfenstein.weps = WEP_KNIFE|WEP_PISTOL
		ChangeWeapon(player, WEP_PISTOL, true)
		
		//respawn with extra guns at higher emerald counts
		if (emeraldCount > 6) then
			player.wolfenstein.weps = WEP_KNIFE|WEP_PISTOL|WEP_MACHINEGUN|WEP_CHAINGUN
			ChangeWeapon(player, 4, true)
		elseif (emeraldCount > 2) then
			player.wolfenstein.weps = WEP_KNIFE|WEP_PISTOL|WEP_MACHINEGUN
			ChangeWeapon(player, 3, true)
		end
	else
		if (emeraldCount > 6) then
			player.wolfenstein.weps = WEP_KNIFE|WEP_PISTOL|WEP_MACHINEGUN|WEP_CHAINGUN
			ChangeWeapon(player, 4, true)
		elseif (emeraldCount > 2) then
			player.wolfenstein.weps = WEP_KNIFE|WEP_PISTOL|WEP_MACHINEGUN
			ChangeWeapon(player, 3, true)
		end
	end
end
addHook("PlayerSpawn", WolfSetup)

//make sure health is 0 on death
local function WolfensteinDeath(mo)
	if (mo.skin == "bj")
		if (mo.player)
		and (mo.player.wolfenstein) then
			mo.player.wolfenstein.health = 0
			mo.player.wolfenstein.deathtime = leveltime
			S_SetInternalMusicVolume(0, mo.player)
			mo.player.lives = $1 - 1
		end
		
		mo.state = S_WOLF_BJDIE
		mo.flags = MF_NOCLIPTHING
		mo.type = MT_GFZFLOWER1
		S_StartSound(mo, sfx_bjdie)
		mo.friction = FRACUNIT/2
		return true
	end
end
addHook("MobjDeath", WolfensteinDeath, MT_PLAYER)

local function WolfensteinGetNextWeapon(player, mod)
	local num = player.wolfenstein.wep + mod
	
	for i = 1, 10, 1 do
		if not (WEAPONS[num])
		or not (player.wolfenstein.weps & WEAPONS[num].req) then
			num = $1 + mod
			
			if (num < 1)
				num = #WEAPONS+1
			elseif (num > #WEAPONS+1)
				num = 1
			end
		else
			return num
		end
	end
	return false
end

local function WeaponsThink(player)

	if not (player.cmd.buttons & BT_WEAPONPREV)
	and not (player.cmd.buttons & BT_WEAPONNEXT) then
		player.wolfenstein.wepchangeheld = false
	end

	if not (player.wolfenstein.wepchangeheld) then
		if (player.cmd.buttons & BT_WEAPONPREV) then
			local wepNum = WolfensteinGetNextWeapon(player, -1)
			
			if (wepNum) then
				ChangeWeapon(player, wepNum)
			end
			player.wolfenstein.wepchangeheld = true
		end
		
		if (player.cmd.buttons & BT_WEAPONNEXT) then
			local wepNum = WolfensteinGetNextWeapon(player, 1)
			
			if (wepNum) then
				ChangeWeapon(player, wepNum)
			end
			player.wolfenstein.wepchangeheld = true
		end
	end

	if (player.cmd.buttons & BT_WEAPONMASK)
	and (player.cmd.buttons & BT_WEAPONMASK <= #WEAPONS+1) then
		ChangeWeapon(player, player.cmd.buttons & BT_WEAPONMASK)
	end

	//weapon is idle
	if (player.wolfenstein.animdelay == -1) then
		//no ammo
		if not (player.wolfenstein.ammo)
		and not (player.wolfenstein.wep == WEP_KNIFE) then
			return
		end
	
		//let's get shootin'!
		if (player.cmd.buttons & BT_ATTACK)
		and not (player.wolfenstein.fireheld) then
			player.wolfenstein.fireheld = true
			ChangeWeaponState(player, WEAPONSTATES[player.wolfenstein.wepstate].nextstate)
		end
		return
	end

	if (player.wolfenstein.animdelay > 0) then
		player.wolfenstein.animdelay = $1-1
		return
	end
	
	ChangeWeaponState(player, WEAPONSTATES[player.wolfenstein.wepstate].nextstate)
end


local function PreThink()
	for player in players.iterate() do
		if not (player.mo)
		or not (player.mo.valid) then continue end
		
		if not (player.mo.skin == "bj") then
			continue
		end
		
		if (player.wolfenstein.wolfcam) then
			player.aiming = 0
			player.cmd.aiming = 0
		end
		
		
		if not (player.mo.health) then
			continue
		end
		
		if (player.cmd.buttons & BT_SPIN)
		and not (player.pflags & PF_SPINDOWN)
		and (P_IsObjectOnGround(player.mo)) then
			player.wolfenstein.alwaysrun = not $1
			if (player.wolfenstein.alwaysrun) then
				player.normalspeed = skins["bj"].normalspeed
			else
				player.normalspeed = 20*FRACUNIT
			end
		end
	end
end
addHook("PreThinkFrame", PreThink)

local function BustableDetect(player)
	local rover
	
	if (player.mo.momz > 0) then
		rover = player.mo.ceilingrover
	else
		rover = player.mo.floorrover
	end
	
	if not (rover)
	or not (rover.flags & FF_EXISTS)
	or not (rover.flags & FF_BUSTUP) then
		return
	end
	
	if (P_MobjFlip(player.mo)*(player.mo.z+player.mo.height) > (rover.bottomheight+1))
	and (P_MobjFlip(player.mo)*(player.mo.z+player.mo.momz) < (rover.topheight+1))
		EV_CrumbleChain(rover)
		return true
	end
end

local function Movement(player)
	if not (player.mo)
	or not (player.mo.skin == "bj") then
		if not (player.wolfenstein) then
			return
		end
		
		if (player.wolfenstein.active)
			player.wolfenstein.active = 0
			hud.enable("score")
			hud.enable("time")
			hud.enable("rings")
			hud.enable("lives")
		end
		
		return
	end
	
	if not (player.wolfenstein) then return end
	
	BustableDetect(player)
	
	if not (player.wolfenstein.active) then
		player.wolfenstein.active = leveltime + 1
		hud.disable("score")
		hud.disable("time")
		hud.disable("rings")
		hud.disable("lives")
		
		if (CV_FindVar("chasecam").value == 1)
			player.wolfenstein.oldchase = true
		end
	end

	//dead
	if not (player.mo.health) then return end
	
	//player.aiming = 0
	
	if not (player.cmd.buttons & BT_ATTACK) then
		player.wolfenstein.fireheld = false
	end
	
	WeaponsThink(player)
end
addHook("PlayerThink", Movement)

local function WolfPostThink()
	for player in players.iterate do
		if (player.mo) then
			if not (player.mo.skin == "bj") then continue end

			if (player.wolfenstein.wolfcam) then
				if (player.followmobj)
				and (player.followmobj.valid) then
					if not (player.awayviewmobj)
					or not (player.awayviewmobj.valid)
						player.awayviewmobj = player.followmobj
					end
				end
				
				if (player.awayviewmobj == player.followmobj)
					player.awayviewtics = 2
				end
			end
		end
	end
end
addHook("PostThinkFrame", WolfPostThink)


local function UpdateScreenInfo(v)
	local screenWA, screenWB = v.dupx()
	local screenHA, screenHB = v.dupy()

	SCREENWIDTH = (screenWB*320)/screenWA
	SCREENHEIGHT = ((screenHB*200)/screenHA)
end


local faceCount = 0
local faceFrame = 1
local function LookLeftRight(v)
	faceCount = $1 + 1
	
	if (faceCount > v.RandomByte()) then
	
		faceFrame = (v.RandomByte() >> 6)
		
		if (faceFrame == 4)
		or (faceFrame == 0)
			faceFrame = 1
		end
		
		faceCount = 0
	end
end

local faceMod = {
	"",
	"L",
	"R"
}

local function GetFacePatch(v, player, endlevel)
	local faceNum = 7-(7*player.wolfenstein.health)/100
	if (faceNum == 0) then
		faceNum = 1
	end
	
	if not (endlevel)
		LookLeftRight(v)
		
		if (player.wolfenstein.health <= 0)
		or (player.mo)
		and (player.mo.health == 0) then
			return v.cachePatch("WOLFDEAD")
		end
	end
	
	if (player.powers[pw_invulnerability])
	or (faceFrame == -1)
		return v.cachePatch("WOLFGRIN")
	end
	
	if (player.pflags & PF_GODMODE) then
		return v.cachePatch("WOLFWIMP")
	end

	return v.cachePatch("WOLFHEAD\$faceNum\\$faceMod[faceFrame]\")
end

local function IsLockedFirstPerson(player)
	if (player.wolfenstein.wolfcam)
		if not (player.awayviewmobj)
		or (player.mo)
		and (player.followmobj)
		and (player.awayviewmobj == player.followmobj)
			if (player.awayviewtics) then
				return true
			end
		end
	end
end

local function NoCrosshair(player, cam)
	if not (cam.chase) then
		if not(leveltime == player.wolfenstein.active)
			player.wolfenstein.wolfcam = not player.wolfenstein.wolfcam
		end
		cam.chase = true
	end
end


local ENEMIESCOUNT = 0
local ENEMIESKILLED = 0
local RINGSCOUNT = 0
local RINGSCOLLECTED = 0
local SECRETSCOUNT = 0
local SECRETSGET = 0
local OLDCHECKPOINT = -1

local SPENEMIESCOUNT = 0
local SPENEMIESKILLED = 0
local SPRINGSCOUNT = 0
local SPRINGSCOLLECTED = 0
local SPSECRETSCOUNT = 0
local SPSECRETSGET = 0

local function TrackStatCounts()
	if not (consoleplayer) then return end
	
	if (consoleplayer.starpostnum > OLDCHECKPOINT)  then
		OLDCHECKPOINT = consoleplayer.starpostnum
		SPENEMIESKILLED = ENEMIESKILLED
		SPENEMIESCOUNT = ENEMIESCOUNT
		
		SPRINGSCOUNT = RINGSCOUNT
		SPRINGSCOLLECTED = RINGSCOLLECTED
		
		SPSECRETSCOUNT = SECRETSCOUNT
		SPSECRETSGET = SECRETSGET
	end
end

local CURRENTSKIN = "sonic"
local CURRENTSCORE = 0

local function WolfenHUD(v, player, cam, endlevel, forcescore)
	UpdateScreenInfo(v)
	TrackStatCounts()
	
	if not (endlevel)
		CURRENTSKIN = skins[player.skin].name
		CURRENTSCORE = player.score
	end

	if not (player.wolfenstein) then
		return
	end
	
	if not (player.wolfenstein.active) then
		if (player.wolfenstein.oldchase) then
			cam.chase = player.wolfenstein.oldchase
			player.wolfenstein.oldchase = nil
		end
		return
	end
	
	if (player.pflags & PF_ANALOGMODE)
		v.drawString(20, 40, "THE AUTOMATIC PLAY STYLE IS NOT\nSUPPORTED!\n\nPLEASE SWITCH TO EITHER MANUAL\nOR STRAFE UNDER CONTROL OPTIONS!", V_REDMAP|V_SNAPTOTOP|V_SNAPTOLEFT|V_PERPLAYER)
	end
	
	if (cam) then 
		NoCrosshair(player, cam)
	end
	
	
	if (player.wolfenstein.deathtime)
	and not (endlevel)
		if (player.wolfenstein.wolfcam)
			local camZ
			if (player.mo.eflags & MFE_VERTICALFLIP)
				camZ = (player.mo.z + player.mo.height) - (8*player.mo.scale)
			else
				camZ = player.mo.z + 8*player.mo.scale
			end
			P_TeleportCameraMove(cam, player.mo.x, player.mo.y, camZ)
			
			local deathFade = leveltime - player.wolfenstein.deathtime
			if (deathFade < 0) then
				deathFade = 0
			elseif (deathFade > 10) then
				deathFade = 10
			end
			
			v.fadeScreen(44, deathFade)
		end
	end
	
	local hudPatch = v.cachePatch("WOLFHUD")
	local hudScale = FRACUNIT
	
	local posX = 0
	local posY = (200*FRACUNIT) - (hudPatch.height*FRACUNIT)
	
	//draw weapon
	local wepPatch = v.cachePatch(WEAPONSTATES[player.wolfenstein.wepstate].graphic)
	if not (endlevel)
	and not (player.wolfenstein.deathtime)
		if not (cam.chase)
		or (IsLockedFirstPerson(player))
			local patchFlags = V_SNAPTOBOTTOM
			local wepYPos = posY
			//flipcam off, flip gun
			if (player.mo.eflags & MFE_VERTICALFLIP)
			and not (CV_FindVar("flipcam").value) then
				patchFlags = V_SNAPTOTOP
				wepYPos = 0
				wepPatch = v.cachePatch(WEAPONSTATES[player.wolfenstein.wepstate].graphic.."F")
			end
			
			v.drawScaled((hudPatch.width*hudScale)/2, wepYPos, hudScale*2, wepPatch, patchFlags|V_PERPLAYER, v.getColormap("bj", player.skincolor))
		end
	end
	
	
	v.drawFill(0, 200 - hudPatch.height, SCREENWIDTH, hudPatch.height, 127|V_SNAPTOLEFT|V_SNAPTOBOTTOM|V_PERPLAYER) 
	v.drawScaled(posX, posY, hudScale, hudPatch, V_SNAPTOBOTTOM|V_PERPLAYER)
	
	//draw face
	local facePatch = v.cachePatch("WOLFHEAD1")
	facePatch = GetFacePatch(v, player, endlevel)
	v.drawScaled(posX+(136*hudScale), posY+(4*hudScale), hudScale, facePatch, V_SNAPTOBOTTOM|V_PERPLAYER)
	
	//draw weapon selection
	local wepInvPatches = {
	"WOLFWEP1",
	"WOLFWEP2",
	"WOLFWEP3",
	"WOLFWEP4"
	}
	
	if (wepInvPatches[player.wolfenstein.wep]) then
		local selPatch = v.cachePatch(wepInvPatches[player.wolfenstein.wep])
		v.drawScaled(posX+(249*hudScale)+(6*hudScale), posY+(5*hudScale)+(3*hudScale), hudScale, selPatch, V_SNAPTOBOTTOM|V_PERPLAYER)
	end
	
	/*
	//draw key
	local keyPatch = v.cachePatch("WOLFKEY0")
	v.drawScaled(posX+(240*hudScale), posY+(4*hudScale), hudScale, keyPatch, V_SNAPTOBOTTOM|V_PERPLAYER)
	
	//second key slot
	local keyPatch2 = v.cachePatch("WOLFKEY0")
	v.drawScaled(posX+(240*hudScale), posY+(4*hudScale)+(keyPatch.height*hudScale), hudScale, keyPatch2, V_SNAPTOBOTTOM|V_PERPLAYER)
	*/
	
	//autorun off indicator
	if not (player.wolfenstein.alwaysrun) then
		local noRunPatch = v.cachePatch("WOLFAUTOR")
		v.drawScaled(posX, posY, hudScale, noRunPatch, V_SNAPTOBOTTOM|V_PERPLAYER)
	end
	
	//
	//TEXT DRAWING
	//
	
	local numberPatches = {}
	for i = 0, 9, 1 do
		numberPatches[i+1] = v.cachePatch("WOLFNUM\$i\")
	end
	
	local TEXTHEIGHT = posY+(16*hudScale)
	local floorNum = "0"
	
	if (mapheaderinfo[gamemap].actnum) then
		floorNum = tostring(mapheaderinfo[gamemap].actnum)
	end
	
	local scoreNum
	
	//use score on exit until total ends
	if (endlevel)
		scoreNum = tostring(forcescore)
	else
		scoreNum = tostring(player.score)
	end
	
	if (string.len(scoreNum) > 6) then
		scoreNum = "999999"
	end
	
	//number, horizontal position
	local hudNumbers = {
	{floorNum, 25},
	{player.lives, 116},
	{scoreNum, 88},
	{player.wolfenstein.health, 184},
	{player.wolfenstein.ammo, 224}
	}
	
	for _,val in ipairs(hudNumbers)
		val[1] = tostring($1)
		for i = 1, string.len(val[1])
			//read the number right to left
			local patch = numberPatches[tonumber(string.sub(val[1], string.len(val[1])-i+1, string.len(val[1])-i+1))+1]
			
			v.drawScaled(posX+(val[2]*hudScale)-(patch.width*(i-1)*hudScale), TEXTHEIGHT, hudScale, patch, V_SNAPTOBOTTOM|V_PERPLAYER)
		end
	end
	
	if not (endlevel) then
		if (player.wolfenstein.lastpickup)
		and (player.wolfenstein.lastpickuptime > leveltime - 20)
		and (player.wolfenstein.lastpickuptime < leveltime + 20)
			local fadeTime = 20 - (leveltime - player.wolfenstein.lastpickuptime)
			fadeTime = $1 /3
			if (fadeTime > 5) then
				fadeTime = 5
			end
			if (fadeTime < 0) then
				fadeTime = 0
			end
			v.fadeScreen(player.wolfenstein.lastpickup, fadeTime)
		end
	end
end
hud.add(WolfenHUD)

local which = 0
local function BreathingPortrait(v, player)
	/*if not (leveltime % 55)
		which = $1 ^^ 1
	end*/
	//local breathPatch = v.cachePatch("BJBREATH\$which\")
	local breathPatch = v.cachePatch("BJBREATH1")
	v.draw(0, 16, breathPatch, V_SNAPTOBOTTOM, v.getColormap("bj", player.skincolor))
end

//
// LEVEL CLEAR
//


local function CreateFont(v)
	local font = {}
	//freeslot the capital letters
	for i = 65, 65+25, 1 do
		local letterPatch = string.char(i)
		font[i] = v.cachePatch("WLFT\$letterPatch\")
	end
	
	//numbers and symbols
	local extraSymbols = {
		"!", ":", "%", "'", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9", "0"
	}

	for _,letterPatch in ipairs(extraSymbols) do
		local letterPatch = string.byte(letterPatch)
		font[letterPatch] = v.cachePatch("WLFT\$letterPatch\")
	end
	
	return font
end

local function DrawCustomString(v, str, mainXOffset, mainYOffset)
	local infernoLetters = CreateFont(v)
	local textScale = FRACUNIT
	
	//get base screenwidth & height
	local screenWA, screenWB = v.dupx()
	local screenHA, screenHB = v.dupy()

	//local SCREENWIDTH = (((screenWB*320)/screenWA)/FRACUNIT)
	//local SCREENHEIGHT = (((screenHB*200)/screenHA)/FRACUNIT)
	
	str = string.upper(str)
	
	local hudText = {}
	
	local tMod = 0
	for i = 1, string.len(str) do
		local curChar = string.sub(str, i, i)
		
		hudText[i-tMod] = string.byte(curChar)
	end


	local totalWidth = 0
	//get width of current line
	for _,val in ipairs(hudText) do
		if (infernoLetters[val]) then
			totalWidth = $1 + infernoLetters[val].width
		else
			totalWidth = $1 + 16
		end
	end

	//BIG LETTERS
	local xOffset = 0
	local yOffset = 0
	//for row,rowT in ipairs(hudText) do
		local currentWidth = 0
		
		for pos, val in ipairs(hudText) do
			if (val == 32) then 
				currentWidth = $1+16
				continue
			end
			
			
			local CHARWIDTH = infernoLetters[val].width
			local CHARHEIGHT = infernoLetters[val].height
			currentWidth = $1 + CHARWIDTH

			
			//get letter's offset based on the position in the word
			xOffset = (currentWidth - CHARWIDTH) * textScale
			yOffset = 0
			
			xOffset = $1 + (mainXOffset * FRACUNIT)
			yOffset = $1 + (mainYOffset * FRACUNIT)
			
			v.drawScaled(xOffset, yOffset, textScale, infernoLetters[val], V_SNAPTOBOTTOM|V_PERPLAYER)
		end
	//end
	
	return totalWidth
end

local function WolfensteinResetCounts()
		ENEMIESCOUNT = 0
		RINGSCOUNT = 0
		SECRETSCOUNT = 0
end
addHook("MapChange", WolfensteinResetCounts)


local INSPECIALSTAGE = false
local INTERMISSIONTIMER = 0
local function ResetIntermissionTimer(mapnum)
	INTERMISSIONTIMER = 0
	hud.enable("intermissiontally")
	hud.enable("intermissionmessages")
	
	INSPECIALSTAGE = G_IsSpecialStage(mapnum)
	
	//store arrest stats on checkpoints in singleplayer
	if not (multiplayer) then
		if (consoleplayer)
		and not (consoleplayer.starpostnum) then
			OLDCHECKPOINT = -1
			ENEMIESKILLED = 0
			RINGSCOLLECTED = 0
			SECRETSGET = 0
		else
			ENEMIESKILLED = SPENEMIESKILLED
			ENEMIESCOUNT = SPENEMIESCOUNT
			
			RINGSCOUNT = SPRINGSCOUNT
			RINGSCOLLECTED = SPRINGSCOLLECTED
			
			SECRETSCOUNT = SPSECRETSCOUNT
			SECRETSGET = SPSECRETSGET
		end
	end
end
addHook("MapLoad", ResetIntermissionTimer)

local function IncreaseKillCounts(mo, inf, src)
	if not (mo.valid) then return end
	
	if (mo.type == MT_RING) then
		RINGSCOLLECTED = $1+1
	elseif (mo.flags & MF_ENEMY) then
		ENEMIESKILLED = $1+1
	elseif (mo.type == MT_TOKEN) then
		SECRETSGET = $1+1
	end
end
addHook("MobjDeath", IncreaseKillCounts)

local function CountEnemies(mo)
	if not (mo.valid) then return end
	
	if (mo.type == MT_RING) then
		RINGSCOUNT = $1+1
	elseif (mo.flags & MF_ENEMY) then
		ENEMIESCOUNT = $1+1
	elseif (mo.type == MT_TOKEN) then
		SECRETSCOUNT = $1+1
	end
end
addHook("MobjSpawn", CountEnemies)


local function GetPercentNum(total, amount, timenow, fulltime, percenttime)
	if (timenow + percenttime<= fulltime) then
		return "   "
	end
	
	//give 100% if there is no tokens/rings/enemies
	local truePercent
	if not (total)
	or (total == 0) then
		truePercent = 100
	else
		truePercent = (amount * 100) / total
	end

	local showPercent = (timenow * 100) / fulltime
	
	if (showPercent > 100) then
		showPercent = 100
	end
	
	truePercent = truePercent * showPercent
	truePercent = $1/100
	
	if (truePercent < 0) then
		truePercent = 0
	elseif (truePercent > 100) then
		truePercent = 100
	end
	
	if (truePercent < 10) then
		truePercent = "  "..truePercent
	elseif (truePercent < 100)
		truePercent = " "..truePercent
	end
	
	return truePercent
end

local function WolfensteinEndScreen(v)
	if not (CURRENTSKIN == "bj") then return end
	if not (consoleplayer) then return end

	if (INSPECIALSTAGE) then
		return
	end

	hud.disable("intermissiontally")
	hud.disable("intermissionmessages")
	
	INTERMISSIONTIMER = $1 + 1	
	
	//end of tally
	//or skipped
	if (S_IdPlaying(sfx_chchng))
	or (S_IdPlaying(sfx_token))
		INTERMISSIONTIMER = 50*TICRATE
	end
	
	if (INTERMISSIONTIMER == 1) then
		S_ChangeMusic("WOLFWI", false, consoleplayer)
	end
	
	
	local FADEINTIME = 15
	if (INTERMISSIONTIMER < FADEINTIME) then
		v.drawFill()
		return
	else
		//screen fill
		v.drawFill(nil, nil, nil, nil, 127)
	end
	
	BreathingPortrait(v, consoleplayer)

	local bonusScore = abs(consoleplayer.score - CURRENTSCORE)
	local scoreOverride = consoleplayer.score - bonusScore
	
	if (INTERMISSIONTIMER >49*TICRATE) then
		scoreOverride = consoleplayer.score
	else
		bonusScore = 0
	end
	
	bonusScore  = tostring($1)
	while (string.len(bonusScore) < 6) do
		bonusScore = " "..$1
	end
	
	if (string.len(bonusScore) > 6) then
		bonusScore = "999999"
	end
	
	local floorNum = "0"
	if (mapheaderinfo[gamemap].actnum) then
		floorNum = tostring(mapheaderinfo[gamemap].actnum)
	end
	
	DrawCustomString(v, "FLOOR \$floorNum\", 108, 16)
	DrawCustomString(v, "COMPLETED", 108, 32)
	DrawCustomString(v, "BONUS \$bonusScore\", 108, 56)
	
	local timerMins = G_TicsToMinutes(leveltime, true)
	local timerSecs = G_TicsToSeconds(leveltime)
	
	if (timerMins > 99) then
		timerMins = 99
		timerSecs = 59
	end
	
	if (timerSecs < 10) then
		timerSecs = "0"..timerSecs
	end
	
	if (timerMins < 10) then
		timerMins = "0"..timerMins
	end
	
	DrawCustomString(v, "TIME \$timerMins\:\$timerSecs\", 124, 80)
	
	local killString = GetPercentNum(ENEMIESCOUNT, ENEMIESKILLED, INTERMISSIONTIMER - FADEINTIME, FADEINTIME + 25, 25)
	local secretString = GetPercentNum(SECRETSCOUNT, SECRETSGET, INTERMISSIONTIMER - FADEINTIME, FADEINTIME + (2*25), 25)
	local treasureString = GetPercentNum(RINGSCOUNT, RINGSCOLLECTED, INTERMISSIONTIMER - FADEINTIME, FADEINTIME + (3*25), 25)
	
	//keep them lined up
	local yPos = 320 - 8 - (string.len("KILL RATIO 100%") * 16)
	DrawCustomString(v, "KILL RATIO \$killString\%", yPos, 112)
	yPos = 320 - 8 - (string.len("SECRET RATIO 100%") * 16)
	DrawCustomString(v, "SECRET RATIO \$secretString\%", yPos, 128)
	yPos = 320 - 8 - (string.len("TREASURE RATIO 100%") * 16)
	DrawCustomString(v, "TREASURE RATIO \$treasureString\%", yPos, 144)

	//draw original hud without weapon
	//and overwrite score display until bonus is shown
	WolfenHUD(v, consoleplayer, nil, true, scoreOverride)
	
	//fade in
	if (INTERMISSIONTIMER < 25) then
		v.fadeScreen(31, 25 - INTERMISSIONTIMER)
	end
end
hud.add(WolfensteinEndScreen, "intermission")



//
//
//
//
//

freeslot(
"MT_WOLFDOGFOOD",
"MT_WOLFFOOD",
"MT_WOLFMEDKIT",
"MT_WOLFMGUNPICKUP",
"S_WOLFMGUNPICKUP",
"MT_WOLFCGUNPICKUP",
"S_WOLFCGUNPICKUP",
"S_WOLFTREASURE",
"S_WOLFDOGFOOD",
"S_WOLFFOOD",
"S_WOLFMEDKIT",
"MT_WOLFAMMO",
"S_WOLFAMMO",
"SPR_WPCK",
"sfx_wammo",
"sfx_wmedic",
"sfx_wfood",
"sfx_wcgpic",
"sfx_wmgpic"
)

mobjinfo[MT_WOLFMGUNPICKUP] = {
	spawnstate = S_WOLFMGUNPICKUP,
	radius = 18*FRACUNIT,
	height = 32*FRACUNIT,
	flags = MF_SPECIAL,
	attacksound = sfx_wmgpic,
	damage = 3,
	spawnhealth = 4
}
states[S_WOLFMGUNPICKUP] = {SPR_WPCK, G, -1, nil, 0, 0, S_NULL}

mobjinfo[MT_WOLFCGUNPICKUP] = {
	spawnstate = S_WOLFCGUNPICKUP,
	radius = 18*FRACUNIT,
	height = 32*FRACUNIT,
	flags = MF_SPECIAL,
	attacksound = sfx_wcgpic,
	damage = 4,
	spawnhealth = 8
}
states[S_WOLFCGUNPICKUP] = {SPR_WPCK, H, -1, nil, 0, 0, S_NULL}


/*
A DOGFOOD
B GOLD KEY
C SILVER KEY
D CHICKEN
E MEDKIT
F AMMO
G MACHINEGUN
H CHAINGUN
I CROSS
J GOBLET
K CHEST
L CROWN
M LIFE ORB
*/


mobjinfo[MT_WOLFAMMO] = {
	doomednum = 2862,
	spawnstate = S_WOLFAMMO,
	radius = 18*FRACUNIT,
	height = 8*FRACUNIT,
	flags = MF_SPECIAL
}

states[S_WOLFAMMO] = {SPR_WPCK, F, -1, nil, 0, 0, S_NULL}

local function ChangeHealth(player, amount, inf, src)
	if (player.wolfenstein.health + amount >= 100) then
		player.wolfenstein.health = 100
	elseif (player.wolfenstein.health + amount <= 0) then
		player.wolfenstein.health = 0
		P_KillMobj(player.mo, inf, src)
	else
		player.wolfenstein.health = $1+amount
	end
end

local function WolfensteinDamage(mo, inf, src, dmg, dmgtype)

	if not (mo.skin == "bj")
	or not (mo.player)
	or not (mo.player.wolfenstein)
	or (mo.player.powers[pw_shield]) then
		return
	end

	local dist = 0
	
	if (src)
	and (inf)
	and (inf.flags & MF_MISSILE) then
		local isMissile = true
		dist = R_PointToDist2(src.x, src.y, src.x, src.y)/FRACUNIT
		dist = $1/64
	end
	
	//generate damage to be taken
	local damage = P_RandomRange(96, 255)/16
	damage = $1*dmg
	
	ChangeHealth(mo.player, -damage, inf, src)
	
	mo.player.powers[pw_flashing] = TICRATE/2
	
	mo.player.wolfenstein.lastpickup = 44
	mo.player.wolfenstein.lastpickuptime = leveltime
	return true
end

addHook("MobjDamage", WolfensteinDamage, MT_PLAYER)

local function ChangeAmmo(player, amount)
	if (player.wolfenstein.ammo + amount > 99) then
		player.wolfenstein.ammo = 99
	else
		player.wolfenstein.ammo = $1+amount
	end
end

local function HealthPickup(mo, pmo)
	if not (pmo.player)
	or not (pmo.skin == "bj")
	or not (pmo.player.wolfenstein) then
		return true
	end
	
	ChangeHealth(pmo.player, mo.health)
	S_StartSound(pmo, mobjinfo[mo.type].attacksound)
end
addHook("TouchSpecial", HealthPickup, MT_WOLFMEDKIT)
addHook("TouchSpecial", HealthPickup, MT_WOLFDOGFOOD)
addHook("TouchSpecial", HealthPickup, MT_WOLFFOOD)


local function WeaponPickup(mo, pmo)
	if not (pmo.player)
	or not (pmo.skin == "bj")
	or not (pmo.player.wolfenstein) then
		return true
	end
	
	//already got the weapon
	if (pmo.player.wolfenstein.weps & mobjinfo[mo.type].spawnhealth)
	and (pmo.player.wolfenstein.ammo > 98)
		return true
	end
	
	
	if (mobjinfo[mo.type].spawnhealth == WEP_CHAINGUN)
	and (consoleplayer)
	and (pmo.player == consoleplayer) then //smile locally!
		faceFrame = -1 //smile!
		faceCount = -5 //for at least a little bit!
	end
	
	S_StartSound(pmo, mobjinfo[mo.type].attacksound)
	ChangeAmmo(pmo.player, 6)
	
	//switch to weapon if it's new
	if not (pmo.player.wolfenstein.weps & mobjinfo[mo.type].spawnhealth) then
		pmo.player.wolfenstein.weps = $1|mobjinfo[mo.type].spawnhealth
		ChangeWeapon(pmo.player, mobjinfo[mo.type].damage, true)
	end
end
addHook("TouchSpecial", WeaponPickup, MT_WOLFMGUNPICKUP)
addHook("TouchSpecial", WeaponPickup, MT_WOLFCGUNPICKUP)


local function AmmoPickup(mo, pmo)
	if not (pmo.player)
	or not (pmo.skin == "bj")
	or not (pmo.player.wolfenstein) then
		return true
	end
	
	//max ammo, don't pick up
	if (pmo.player.wolfenstein.ammo > 98) then
		return true
	end
	
	local ammoCount = 4
	
	if (mo.ammo) then
		ammoCount = mo.ammo
	end
	
	ChangeAmmo(pmo.player, ammoCount)
	S_StartSound(pmo.player.mo, sfx_wammo)
end
addHook("TouchSpecial", AmmoPickup, MT_WOLFAMMO)

local function SpawnAmmo(mo, inf, src)
	if not (mo.flags & MF_ENEMY)
	or not (src)
	or not (src.skin == "bj")
	or not (src.player) then return end

	local mag = P_SpawnMobj(mo.x, mo.y, mo.z, MT_WOLFAMMO)
	mag.ammo = 4
end
addHook("MobjDeath", SpawnAmmo)

//
//
//
//
//

freeslot(
"MT_WOLFITEMOVERLAY",
"sfx_wlife"
)

mobjinfo[MT_WOLFITEMOVERLAY] = {
	spawnstate = S_INVISIBLE,
	flags = MF_NOGRAVITY|MF_NOCLIP|MF_NOCLIPHEIGHT
}

local function SpawnWolfItemOverlay(mo)
	local item = P_SpawnMobj(mo.x, mo.y, mo.z, MT_WOLFITEMOVERLAY)
	item.skin = "bj"
	
	if (mo.type == MT_1UP_BOX)
		item.sprite = SPR_WPCK
		item.frame = M
	elseif (mo.type == MT_RING_BOX)
		item.sprite = SPR_WPCK
		local rand = P_RandomByte()
		
		if (rand > 100) then //medkit
			item.frame = E
		elseif (rand < 20) then //chaingun
			item.frame = H
		else //machinegun
			item.frame = G
		end
	end
	
	item.flags2 = $1|MF2_DONTDRAW
	return item
end

local function AddBox(mo)
	mo.wolfitem = SpawnWolfItemOverlay(mo)
end
addHook("MobjSpawn", AddBox, MT_1UP_BOX)

local function RemoveOverlay(mo)
	if (mo.wolfitem)
	and (mo.wolfitem.valid) then
		P_RemoveMobj(mo.wolfitem)
	end
end
addHook("MobjRemoved", RemoveOverlay, MT_1UP_BOX)
addHook("MobjRemoved", RemoveOverlay, MT_RING_BOX)

local function ItemWasGrabbed(mo, player, cantedit)
	if not (player.wolfenstein)
		return
	end
	
	if (mo.type == MT_1UP_BOX)
		if not (mo.health) then
			return true
		else
			return false
		end
	end

	if not (player.wolfenstein.grabbeditems)
	or not (#player.wolfenstein.grabbeditems) then
		return
	end
	
	local wasGrabbed = false
	for pos, val in ipairs(player.wolfenstein.grabbeditems) do
		//doesn't exist any more
		if not (val)
		or not (val.valid) then
			//dont mess with it in consoleplayer calls
			if (cantedit) then
				table.remove(player.wolfenstein.grabbeditems, val)
			end
			continue
		end
		
		if (val == mo) then
			wasGrabbed = true
			break
		end
	end
	
	return wasGrabbed
end

local function BoxCheck(mo)
	if not (mo.wolfitem)
	or not (mo.wolfitem.valid) then
		mo.wolfitem = SpawnWolfItemOverlay(mo)
	end
	
	P_MoveOrigin(mo.wolfitem, mo.x, mo.y, mo.z)

	if not (consoleplayer) then return end
	local wasGrabbed = ItemWasGrabbed(mo, consoleplayer, true)

	if not (consoleplayer.mo)
	or not (consoleplayer.mo.skin == "bj")
		mo.wolfitem.flags2 = $1|MF2_DONTDRAW
		mo.flags2 = $1 & ~MF2_DONTDRAW
		if (mo.tracer) then
			mo.tracer.flags2 = $1 & ~MF2_DONTDRAW
		end
	else
		mo.flags2 = $1|MF2_DONTDRAW
		
		if (wasGrabbed)
			mo.wolfitem.flags2 = $1|MF2_DONTDRAW
		else
			mo.wolfitem.flags2 = $1 & ~MF2_DONTDRAW
		end
		
		if (mo.tracer) then
			mo.tracer.flags2 = $1|MF2_DONTDRAW
		end
	end
end
addHook("MobjThinker", BoxCheck, MT_1UP_BOX)
addHook("MobjThinker", BoxCheck, MT_RING_BOX)

//only show items when bj
local function HidePickups(mo)
	
	if not (consoleplayer)
	or not (consoleplayer.mo)
	or not (consoleplayer.mo.skin == "bj") then
		mo.flags2 = $1|MF2_DONTDRAW
	else
		mo.flags2 = $1 & ~MF2_DONTDRAW
	end
end
addHook("MobjThinker", HidePickups, MT_WOLFMEDKIT)
addHook("MobjThinker", HidePickups, MT_WOLFAMMO)

//touching monitor?
local function MonitorHeightCheck(player, mo)
	if (P_MobjFlip(player.mo)*(player.mo.z - (mo.z)) > -(2*player.mo.scale))
	and (P_MobjFlip(player.mo)*(player.mo.z - (mo.z)) < mo.height+(2*player.mo.scale))
		return true
	end
end

//dont get crushed by collectibles
local function DontCrushBJ(tmo, mo)
	if (mo.skin == "bj") then
		return false
	end
end
addHook("MobjMoveCollide", DontCrushBJ, MT_1UP_BOX)
addHook("MobjMoveCollide", DontCrushBJ, MT_RING_BOX)

local function DontShootPickups(tmo, mo)
	if (mo.type == MT_WOLFBULLET) then
		return false
	end
end
addHook("MobjCollide", DontShootPickups, MT_RING_BOX)
addHook("MobjCollide", DontShootPickups, MT_1UP_BOX)


local function CanPickUpWeapon(mo, wep)
	local pick = WEP_MACHINEGUN
	
	if (wep.frame == H) then
		pick = WEP_CHAINGUN
	end
	
	if (mo.player)
	and (mo.player.wolfenstein) then
		if not (mo.player.wolfenstein.weps & pick)
		or (mo.player.wolfenstein.ammo < 99)
			return true
		end
	end
end

//dont pick up health at max hp
local function NoclipPickup(tmo, mo)
	if (mo.skin == "bj")
	and (mo.player)
	and (mo.player.wolfenstein)
	and (tmo.wolfitem)

		if (tmo.wolfitem.frame == E)
		and (mo.player.wolfenstein.health >= 100)
		or (tmo.wolfitem.frame == G)
		and not (CanPickUpWeapon(mo, tmo.wolfitem))
		or (tmo.wolfitem.frame == H)
		and not (CanPickUpWeapon(mo, tmo.wolfitem))
		or (ItemWasGrabbed(tmo, mo.player))
			return false
		end
	end
end
addHook("MobjCollide", NoclipPickup, MT_RING_BOX)

//lesser A_MonitorPop
local function CollectBox(player, mo)

	if not (player.mo.skin == "bj") then
		return
	end

	if not (mo)
	or not (mo.valid)
		return
	end
	
	if not (mo.type == MT_1UP_BOX)
	and not (mo.type == MT_RING_BOX)
		return
	end

	if not (mo.health)
	and not (mo.type == MT_RING_BOX) then
		return
	end
	
	if not (mo.wolfitem) then return end

	if not (MonitorHeightCheck(player, mo)) then
		return
	end

	if (ItemWasGrabbed(mo, player))
		return
	end

	if (mo.type == MT_1UP_BOX)
		P_GivePlayerLives(player, 1)
		ChangeAmmo(player, 25)
		ChangeHealth(player, 99)
		S_StartSound(player.mo, sfx_wlife, player)
	else
		if (mo.wolfitem.frame == E) then
			if (player.wolfenstein.health >= 100) then
				return
			end
			ChangeHealth(player, 25)
			S_StartSound(player.mo, sfx_wmedic, player)
		else
			
			local getWep = MT_WOLFMGUNPICKUP
			if (mo.wolfitem.frame == H) then
				getWep = MT_WOLFCGUNPICKUP
			end
			
			mo.type = getWep
			if (WeaponPickup(mo, player.mo))//if it r eturns true item wasn't pcked up
				mo.type = MT_RING_BOX
				return
			end
			mo.type = MT_RING_BOX
		end
		
		table.insert(player.wolfenstein.grabbeditems, mo)
	end


	mo.state = S_BOX_POP2
	mo.target = player.mo
	local newmobj = P_SpawnMobjFromMobj(mo, 0, 0, 13*FRACUNIT, mo.info.damage)
	mo.health = 0
	mo.flags = $1|MF_NOCLIP
	
	if (mo.tracer) // Remove the old lives icon.
		P_RemoveMobj(mo.tracer)
	end
	
	//hide the spawn icon when playing BJ
	if  (consoleplayer)
	and (consoleplayer.mo)
	and (consoleplayer.mo.skin == "bj") then
		if (livesico) then
			livesico.flags2 = $1|MF2_DONTDRAW
			P_RemoveMobj(livesico)
		end
		newmobj.flags2 = $1|MF2_DONTDRAW
		newmobj.sprite = SPR_NULL
	end
	return false
end
addHook("PlayerCanDamage", CollectBox)